==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/extmenus_001/ExtMenus.java <==

package net.datastream.schemas.mp_entities.extmenus_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMAINMENUTYPE_Type;
import net.datastream.schemas.mp_fields.EXTMENUID_Type;
import net.datastream.schemas.mp_fields.FUNCTIONID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMAINMENUTYPE" minOccurs="0"/>
 *         <element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extmenuid",
    "usergroupid",
    "functionid",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "extmainmenutype",
    "updatecount"
})
@XmlRootElement(name = "ExtMenus")
public class ExtMenus {

    @XmlElement(name = "EXTMENUID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EXTMENUID_Type extmenuid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "FUNCTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "EXTMENUPARENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU", namespace = "http://schemas.datastream.net/MP_fields")
    protected String hidemenu;
    @XmlElement(name = "MOBILE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobile;
    @XmlElement(name = "MOBILEICON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobileicon;
    @XmlElement(name = "EXTMAINMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    @XmlSchemaType(name = "string")
    protected EXTMAINMENUTYPE_Type extmainmenutype;
    @XmlElement(name = "UPDATECOUNT")
    protected Long updatecount;

    /**
     * Gets the value of the extmenuid property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public EXTMENUID_Type getEXTMENUID() {
        return extmenuid;
    }

    /**
     * Sets the value of the extmenuid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public void setEXTMENUID(EXTMENUID_Type value) {
        this.extmenuid = value;
    }

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the extmenuparent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Sets the value of the extmenuparent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Gets the value of the extmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Sets the value of the extmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the hidemenu property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Sets the value of the hidemenu property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Gets the value of the mobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Sets the value of the mobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Gets the value of the mobileicon property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Sets the value of the mobileicon property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Gets the value of the extmainmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public EXTMAINMENUTYPE_Type getEXTMAINMENUTYPE() {
        return extmainmenutype;
    }

    /**
     * Sets the value of the extmainmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public void setEXTMAINMENUTYPE(EXTMAINMENUTYPE_Type value) {
        this.extmainmenutype = value;
    }

    /**
     * Gets the value of the updatecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Sets the value of the updatecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUPDATECOUNT(Long value) {
        this.updatecount = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/extmenus_001/ExtMenus.java <==

package net.datastream.schemas.mp_entities.extmenus_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMAINMENUTYPE_Type;
import net.datastream.schemas.mp_fields.EXTMENUID_Type;
import net.datastream.schemas.mp_fields.FUNCTIONID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMAINMENUTYPE" minOccurs="0"/>
 *         &lt;element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extmenuid",
    "usergroupid",
    "functionid",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "extmainmenutype",
    "updatecount"
})
@XmlRootElement(name = "ExtMenus")
public class ExtMenus {

    @XmlElement(name = "EXTMENUID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EXTMENUID_Type extmenuid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "FUNCTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "EXTMENUPARENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU", namespace = "http://schemas.datastream.net/MP_fields")
    protected String hidemenu;
    @XmlElement(name = "MOBILE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobile;
    @XmlElement(name = "MOBILEICON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobileicon;
    @XmlElement(name = "EXTMAINMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    @XmlSchemaType(name = "string")
    protected EXTMAINMENUTYPE_Type extmainmenutype;
    @XmlElement(name = "UPDATECOUNT")
    protected Long updatecount;

    /**
     * Gets the value of the extmenuid property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public EXTMENUID_Type getEXTMENUID() {
        return extmenuid;
    }

    /**
     * Sets the value of the extmenuid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public void setEXTMENUID(EXTMENUID_Type value) {
        this.extmenuid = value;
    }

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the extmenuparent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Sets the value of the extmenuparent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Gets the value of the extmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Sets the value of the extmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the hidemenu property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Sets the value of the hidemenu property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Gets the value of the mobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Sets the value of the mobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Gets the value of the mobileicon property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Sets the value of the mobileicon property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Gets the value of the extmainmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public EXTMAINMENUTYPE_Type getEXTMAINMENUTYPE() {
        return extmainmenutype;
    }

    /**
     * Sets the value of the extmainmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public void setEXTMAINMENUTYPE(EXTMAINMENUTYPE_Type value) {
        this.extmainmenutype = value;
    }

    /**
     * Gets the value of the updatecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Sets the value of the updatecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUPDATECOUNT(Long value) {
        this.updatecount = value;
    }

}
